@@ -1,5 +1,5 @@
-/*!
- * \copyright Copyright (c) 2020-2021 Governikus GmbH & Co. KG, Germany
+/**
+ * Copyright (c) 2020-2025 Governikus GmbH & Co. KG, Germany
  */
 
 #pragma once
@@ -15,14 +15,19 @@ class TestWorkflowContext
 	Q_OBJECT
 
 	public:
-		TestWorkflowContext(bool pCanAllowed = false);
+		TestWorkflowContext(bool pCanAllowed = false, Action pAction = Action::AUTH);
 		~TestWorkflowContext() override = default;
 
 		[[nodiscard]] bool isCanAllowedMode() const override;
 		void setCanAllowedMode(bool pCanAllowed);
 
+
+		[[nodiscard]] virtual QList<AcceptedEidType> getAcceptedEidTypes() const override;
+		void setAcceptedEidTypes(const QList<AcceptedEidType>& pAcceptedEidTypes);
+
 	private:
 		bool mCanAllowed;
+		QList<AcceptedEidType> mAcceptedEidTypes;
 };
 
 } // namespace governikus
